@@ -147,7 +147,9 @@ for i, p in enumerate(p_vec):
     # Call function
     t1 = timer()
     for _j in range(N_iter):
-        test = chol_loglike_1D(v_obs, t, l_corr, std_model, std_meas=std_meas, y_model=y_func)
+        test = chol_loglike_1D(
+            v_obs, t, l_corr, std_model, std_meas=std_meas, y_model=y_func
+        )
     t2 = timer()
 
     t_list.append((t2 - t1) / N_iter)
