@@ -13,6 +13,7 @@ def chol_sample_1D(
     lcorr: Union[float, int],
     y_model: Optional[np.ndarray] = None,
     size: Optional[int] = 1,
+    seed: Optional[int] = None,
 ) -> np.ndarray:
     """
     Efficient sampling from Exponentially correlated MVN distribution in 1D.
@@ -31,6 +32,7 @@ def chol_sample_1D(
         lcorr: Scalar correlation length.
         y_model: [1, N] vector of model predictions.
         size: Number of samples.
+        seed: Optional integer seed passed to `numpy.random.default_rng()`
 
     Returns:
         [size, N] array of samples.
@@ -39,8 +41,9 @@ def chol_sample_1D(
     N = len(coords)
 
     # Sample from std. normal and Gaussian with vector noise
-    X = np.random.default_rng().normal(loc=0.0, scale=1.0, size=(size, N))
-    S = np.random.default_rng().normal(loc=0.0, scale=std_noise, size=(size, N))
+    rng = np.random.default_rng(seed)
+    X = rng.normal(loc=0.0, scale=1.0, size=(size, N))
+    S = rng.normal(loc=0.0, scale=std_noise, size=(size, N))
 
     # Cholesky of inverse correlation matrix
     d0, d1 = inv_cov_vec_1D(coords, lcorr, std_model)
@@ -67,6 +70,7 @@ def kron_sample_2D(
     lcorr_t: Union[float, int],
     y_model: Optional[np.ndarray] = None,
     size: Optional[int] = 1,
+    seed: Optional[int] = None,
 ) -> np.ndarray:
     """
     Efficient sampling from Exponentially correlated MVN distribution in 2D.
@@ -88,6 +92,7 @@ def kron_sample_2D(
         lcorr_t: Scalar temporal correlation length.
         y_model: [Nx, Nt] Array of model predictions.
         size: Scalar number of samples.
+        seed: Optional integer seed passed to `numpy.random.default_rng()`
 
     Returns:
         [size, Nx * Nt] array of samples.
@@ -104,8 +109,9 @@ def kron_sample_2D(
     Lt = chol_tridiag(d0_t, d1_t)
 
     # Sample from std. normal and Gaussian with vector noise
-    X = np.random.default_rng().normal(loc=0.0, scale=1.0, size=(size, Nx * Nt))
-    S = np.random.default_rng().normal(loc=0.0, scale=std_noise, size=(size, Nx * Nt))
+    rng = np.random.default_rng(seed)
+    X = rng.normal(loc=0.0, scale=1.0, size=(size, Nx * Nt))
+    S = rng.normal(loc=0.0, scale=std_noise, size=(size, Nx * Nt))
 
     # Solve for Z
     def solve_func(A, B):
@@ -130,6 +136,7 @@ def kron_sample_ND(
     lcorr: np.ndarray,
     y_model: Optional[np.ndarray] = None,
     size: Optional[int] = 1,
+    seed: Optional[int] = None,
 ) -> np.ndarray:
     """
     Efficient sampling from Exponentially correlated MVN distribution in ND.
@@ -148,6 +155,7 @@ def kron_sample_ND(
         lcorr: [ND, 1] vector of correlation lengths per dim.
         y_model: [N1 x N2 x ... x ND] array of model predictions.
         size: Scalar number of samples.
+        seed: Optional integer seed passed to `numpy.random.default_rng()`
 
     Returns:
         [size, prod(ND)] array of samples.
@@ -165,8 +173,9 @@ def kron_sample_ND(
     Npts = np.prod(Ni)
 
     # Sample from std. normal and Gaussian with vector noise
-    X = np.random.default_rng().normal(loc=0.0, scale=1.0, size=(size, Npts))
-    S = np.random.default_rng().normal(loc=0.0, scale=std_noise, size=(size, Npts))
+    rng = np.random.default_rng(seed)
+    X = rng.normal(loc=0.0, scale=1.0, size=(size, Npts))
+    S = rng.normal(loc=0.0, scale=std_noise, size=(size, Npts))
 
     # Solve for Z across all dimensions
     def solve_func(A, B):
